@@ -11,7 +11,7 @@ Contains a handful of string related functions.
 
 from .datetime_functions import generate_all_datetime_regex
 from .iterable_functions import groupby_count
-from .network_functions import download_file
+from .network_functions import *
 from .string_functions import *
 from .utility_functions import *
 from .fake_useragent import random_useragent
